@@ -18,14 +18,13 @@ __correspondence_email__ = 'alexander.juestel@rwth-aachen.de'
 
 __affiliations__ = 'CGRE - RWTH Aachen University'
 
-__version_date__ = '2023-02-02'
+__version_date__ = '2023-02-07'
 
-__version__ = '1.0.4'
+__version__ = '1.0.6'
 
-__changelog__ = """What is new in version 1.0.4:
+__changelog__ = """What is new in version 1.0.6:
 
-- Added function to extract contour lines from raster
-- Added functions to display seismic data in PyVista
+- Removing pygeo remains
 
 """
 
